{% extends "base.html" %}
{% load static wagtailcore_tags %}

{% block body_class %}template-homepage{% endblock %}

{% block content %}
{% for child in self.content %}
{% include_block child %}
{% endfor %}

{% endblock content %}
